==> kubernetes-model-policy-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/policy/PodDisruptionBudgetListFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodDisruptionBudgetListFluent<A extends PodDisruptionBudgetListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,PodDisruptionBudget item);
    public A setToItems(int index,PodDisruptionBudget item);
    public A addToItems(PodDisruptionBudget... items);
    public A addAllToItems(Collection<PodDisruptionBudget> items);
    public A removeFromItems(PodDisruptionBudget... items);
    public A removeAllFromItems(Collection<PodDisruptionBudget> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<PodDisruptionBudgetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodDisruptionBudget> getItems();
    public List<PodDisruptionBudget> buildItems();
    public PodDisruptionBudget buildItem(int index);
    public PodDisruptionBudget buildFirstItem();
    public PodDisruptionBudget buildLastItem();
    public PodDisruptionBudget buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodDisruptionBudgetBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodDisruptionBudgetBuilder> predicate);
    public A withItems(List<PodDisruptionBudget> items);
    public A withItems(PodDisruptionBudget... items);
    public Boolean hasItems();
    public PodDisruptionBudgetListFluent.ItemsNested<A> addNewItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> addNewItemLike(PodDisruptionBudget item);
    public PodDisruptionBudgetListFluent.ItemsNested<A> setNewItemLike(int index,PodDisruptionBudget item);
    public PodDisruptionBudgetListFluent.ItemsNested<A> editItem(int index);
    public PodDisruptionBudgetListFluent.ItemsNested<A> editFirstItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> editLastItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<PodDisruptionBudgetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetFluent<PodDisruptionBudgetListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> kubernetes-model-policy-5.2.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/policy/PodDisruptionBudgetListFluent.java <==
package io.fabric8.kubernetes.api.model.policy;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodDisruptionBudgetListFluent<A extends PodDisruptionBudgetListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,PodDisruptionBudget item);
    public A setToItems(int index,PodDisruptionBudget item);
    public A addToItems(PodDisruptionBudget... items);
    public A addAllToItems(Collection<PodDisruptionBudget> items);
    public A removeFromItems(PodDisruptionBudget... items);
    public A removeAllFromItems(Collection<PodDisruptionBudget> items);
    public A removeMatchingFromItems(Predicate<PodDisruptionBudgetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<PodDisruptionBudget> getItems();
    public List<PodDisruptionBudget> buildItems();
    public PodDisruptionBudget buildItem(int index);
    public PodDisruptionBudget buildFirstItem();
    public PodDisruptionBudget buildLastItem();
    public PodDisruptionBudget buildMatchingItem(Predicate<PodDisruptionBudgetBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PodDisruptionBudgetBuilder> predicate);
    public A withItems(List<PodDisruptionBudget> items);
    public A withItems(PodDisruptionBudget... items);
    public Boolean hasItems();
    public PodDisruptionBudgetListFluent.ItemsNested<A> addNewItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> addNewItemLike(PodDisruptionBudget item);
    public PodDisruptionBudgetListFluent.ItemsNested<A> setNewItemLike(int index,PodDisruptionBudget item);
    public PodDisruptionBudgetListFluent.ItemsNested<A> editItem(int index);
    public PodDisruptionBudgetListFluent.ItemsNested<A> editFirstItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> editLastItem();
    public PodDisruptionBudgetListFluent.ItemsNested<A> editMatchingItem(Predicate<PodDisruptionBudgetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetFluent<PodDisruptionBudgetListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
